import { Event, Feed, MinimalRepository, Repository, RepositorySubscription, SimpleUser, Stargazer, StarredRepository, Thread, ThreadSubscription, ApiHeroEndpoint } from "./@types";
/**
* @see https://docs.github.com/rest/reference/activity#get-feeds


* Get feeds
* GitHub provides several timeline resources in [Atom](http://en.wikipedia.org/wiki/Atom_(standard)) format. The Feeds API lists all the feeds available to the authenticated user:
 *
 * *   **Timeline**: The GitHub global public timeline
 * *   **User**: The public timeline for any user, using [URI template](https://docs.github.com/rest/overview/resources-in-the-rest-api#hypermedia)
 * *   **Current user public**: The public timeline for the authenticated user
 * *   **Current user**: The private timeline for the authenticated user
 * *   **Current user actor**: The private timeline for activity created by the authenticated user
 * *   **Current user organizations**: The private timeline for the organizations the authenticated user is a member of.
 * *   **Security advisories**: A collection of public announcements that provide information about security-related vulnerabilities in software on GitHub.
 *
 * **Note**: Private feeds are only returned when [authenticating via Basic Auth](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) since current feed URIs use the older, non revocable auth tokens.
*/
export declare const getFeeds: ApiHeroEndpoint<void, Feed>;
/**
* @see https://docs.github.com/rest/reference/activity#list-public-events


* List public events
* We delay the public events feed by five minutes, which means the most recent event returned by the public events API actually occurred at least five minutes ago.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listPublicEvents: ApiHeroEndpoint<{
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#list-repositories-starred-by-the-authenticated-user


* List repositories starred by the authenticated user
* Lists repositories the authenticated user has starred.
 *
 * You can also find out _when_ stars were created by passing the following custom [media type](https://docs.github.com/rest/overview/media-types/) via the `Accept` header:
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [sort] - The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
*/
export declare const listReposStarredByAuthenticatedUser: ApiHeroEndpoint<{
    perPage?: number;
    page?: number;
    direction?: "asc" | "desc";
    sort?: "created" | "updated";
}, Array<Repository>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#list-notifications-for-the-authenticated-user


* List notifications for the authenticated user
* List all notifications for the current user, sorted by most recently updated.
* @param [perPage=30] - The number of results per page (max 100).
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [page=1] - Page number of the results to fetch.
* @param [before] - Only show notifications updated before the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [all=false] - If `true`, show notifications marked as read.
* @param [participating=false] - If `true`, only shows notifications in which the user is directly participating or mentioned.
*/
export declare const listNotificationsForAuthenticatedUser: ApiHeroEndpoint<{
    perPage?: number;
    since?: string;
    page?: number;
    before?: string;
    all?: boolean;
    participating?: boolean;
}, Array<Thread>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#mark-notifications-as-read


* Mark notifications as read
* Marks all notifications as "read" removes it from the [default view on GitHub](https://github.com/notifications). If the number of notifications is too large to complete in one request, you will receive a `202 Accepted` status and GitHub will run an asynchronous process to mark notifications as "read." To check whether any "unread" notifications remain, you can use the [List notifications for the authenticated user](https://docs.github.com/rest/reference/activity#list-notifications-for-the-authenticated-user) endpoint and pass the query parameter `all=false`.
*/
export declare const markNotificationsAsRead: ApiHeroEndpoint<{
    body?: {
        /**
         * Whether the notification has been read.
         */
        read?: boolean;
        /**
         * Describes the last point that notifications were checked. Anything updated since this time will not be marked as read. If you omit this parameter, all notifications are marked as read. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`. Default: The current timestamp.
         */
        last_read_at?: string;
    };
}, {
    message?: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#list-public-organization-events


* List public organization events
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listPublicOrgEvents: ApiHeroEndpoint<{
    org: string;
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#list-repositories-watched-by-the-authenticated-user


* List repositories watched by the authenticated user
* Lists repositories the authenticated user is watching.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listWatchedReposForAuthenticatedUser: ApiHeroEndpoint<{
    perPage?: number;
    page?: number;
}, Array<MinimalRepository>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#list-events-for-the-authenticated-user


* List events for the authenticated user
* If you are authenticated as the given user, you will see your private events. Otherwise, you'll only see public events.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listEventsForAuthenticatedUser: ApiHeroEndpoint<{
    username: string;
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#list-repositories-starred-by-a-user


* List repositories starred by a user
* Lists repositories a user has starred.
 *
 * You can also find out _when_ stars were created by passing the following custom [media type](https://docs.github.com/rest/overview/media-types/) via the `Accept` header:
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [sort] - The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
*/
export declare const listReposStarredByUser: ApiHeroEndpoint<{
    username: string;
    perPage?: number;
    page?: number;
    direction?: "asc" | "desc";
    sort?: "created" | "updated";
}, Array<StarredRepository> | Array<Repository>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#list-repository-events


* List repository events
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listRepoEvents: ApiHeroEndpoint<{
    owner: string;
    repo: string;
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#check-if-a-repository-is-starred-by-the-authenticated-user


* Check if a repository is starred by the authenticated user
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
export declare const checkRepoIsStarredByAuthenticatedUser: ApiHeroEndpoint<{
    owner: string;
    repo: string;
}, void>;
/**
* @see https://docs.github.com/rest/reference/activity#star-a-repository-for-the-authenticated-user


* Star a repository for the authenticated user
* Note that you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
export declare const starRepoForAuthenticatedUser: ApiHeroEndpoint<{
    owner: string;
    repo: string;
}, void>;
/**
* @see https://docs.github.com/rest/reference/activity#unstar-a-repository-for-the-authenticated-user


* Unstar a repository for the authenticated user
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
export declare const unstarRepoForAuthenticatedUser: ApiHeroEndpoint<{
    owner: string;
    repo: string;
}, void>;
/**
* @see https://docs.github.com/rest/reference/activity#list-public-events-for-a-network-of-repositories


* List public events for a network of repositories
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listPublicEventsForRepoNetwork: ApiHeroEndpoint<{
    owner: string;
    repo: string;
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#list-public-events-for-a-user


* List public events for a user
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listPublicEventsForUser: ApiHeroEndpoint<{
    username: string;
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#list-repositories-watched-by-a-user


* List repositories watched by a user
* Lists repositories a user is watching.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listReposWatchedByUser: ApiHeroEndpoint<{
    username: string;
    perPage?: number;
    page?: number;
}, Array<MinimalRepository>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#list-stargazers


* List stargazers
* Lists the people that have starred the repository.
 *
 * You can also find out _when_ stars were created by passing the following custom [media type](https://docs.github.com/rest/overview/media-types/) via the `Accept` header:
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listStargazersForRepo: ApiHeroEndpoint<{
    owner: string;
    repo: string;
    perPage?: number;
    page?: number;
}, Array<SimpleUser> | Array<Stargazer>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#list-watchers


* List watchers
* Lists the people watching the specified repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listWatchersForRepo: ApiHeroEndpoint<{
    owner: string;
    repo: string;
    perPage?: number;
    page?: number;
}, Array<SimpleUser>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#list-events-received-by-the-authenticated-user


* List events received by the authenticated user
* These are events that you've received by watching repos and following users. If you are authenticated as the given user, you will see private events. Otherwise, you'll only see public events.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listReceivedEventsForUser: ApiHeroEndpoint<{
    username: string;
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#get-a-thread


* Get a thread
* @param threadId - The unique identifier of the pull request thread.
*/
export declare const getThread: ApiHeroEndpoint<{
    threadId: number;
}, Thread>;
/**
* @see https://docs.github.com/rest/reference/activity#mark-a-thread-as-read


* Mark a thread as read
* @param threadId - The unique identifier of the pull request thread.
*/
export declare const markThreadAsRead: ApiHeroEndpoint<{
    threadId: number;
}, any>;
/**
* @see https://docs.github.com/rest/reference/activity#get-a-repository-subscription


* Get a repository subscription
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
export declare const getRepoSubscription: ApiHeroEndpoint<{
    owner: string;
    repo: string;
}, RepositorySubscription>;
/**
* @see https://docs.github.com/rest/reference/activity#set-a-repository-subscription


* Set a repository subscription
* If you would like to watch a repository, set `subscribed` to `true`. If you would like to ignore notifications made within a repository, set `ignored` to `true`. If you would like to stop watching a repository, [delete the repository's subscription](https://docs.github.com/rest/reference/activity#delete-a-repository-subscription) completely.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
export declare const setRepoSubscription: ApiHeroEndpoint<{
    owner: string;
    repo: string;
    payload?: {
        /**
         * Determines if all notifications should be blocked from this repository.
         */
        ignored?: boolean;
        /**
         * Determines if notifications should be received from this repository.
         */
        subscribed?: boolean;
    };
}, RepositorySubscription>;
/**
* @see https://docs.github.com/rest/reference/activity#delete-a-repository-subscription


* Delete a repository subscription
* This endpoint should only be used to stop watching a repository. To control whether or not you wish to receive notifications from a repository, [set the repository's subscription manually](https://docs.github.com/rest/reference/activity#set-a-repository-subscription).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
export declare const deleteRepoSubscription: ApiHeroEndpoint<{
    owner: string;
    repo: string;
}, void>;
/**
* @see https://docs.github.com/rest/reference/activity#list-repository-notifications-for-the-authenticated-user


* List repository notifications for the authenticated user
* List all notifications for the current user.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [page=1] - Page number of the results to fetch.
* @param [before] - Only show notifications updated before the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [all=false] - If `true`, show notifications marked as read.
* @param [participating=false] - If `true`, only shows notifications in which the user is directly participating or mentioned.
*/
export declare const listRepoNotificationsForAuthenticatedUser: ApiHeroEndpoint<{
    owner: string;
    repo: string;
    perPage?: number;
    since?: string;
    page?: number;
    before?: string;
    all?: boolean;
    participating?: boolean;
}, Array<Thread>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#mark-repository-notifications-as-read


* Mark repository notifications as read
* Marks all notifications in a repository as "read" removes them from the [default view on GitHub](https://github.com/notifications). If the number of notifications is too large to complete in one request, you will receive a `202 Accepted` status and GitHub will run an asynchronous process to mark notifications as "read." To check whether any "unread" notifications remain, you can use the [List repository notifications for the authenticated user](https://docs.github.com/rest/reference/activity#list-repository-notifications-for-the-authenticated-user) endpoint and pass the query parameter `all=false`.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
export declare const markRepoNotificationsAsRead: ApiHeroEndpoint<{
    owner: string;
    repo: string;
    payload?: {
        /**
         * Describes the last point that notifications were checked. Anything updated since this time will not be marked as read. If you omit this parameter, all notifications are marked as read. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`. Default: The current timestamp.
         */
        last_read_at?: string;
    };
}, {
    url?: string;
    message?: string;
}>;
/**
* @see https://docs.github.com/rest/reference/activity#list-organization-events-for-the-authenticated-user


* List organization events for the authenticated user
* This is the user's organization dashboard. You must be authenticated as the user to view this.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listOrgEventsForAuthenticatedUser: ApiHeroEndpoint<{
    org: string;
    username: string;
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#list-public-events-received-by-a-user


* List public events received by a user
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listReceivedPublicEventsForUser: ApiHeroEndpoint<{
    username: string;
    perPage?: number;
    page?: number;
}, Array<Event>>;
/**
* @see https://docs.github.com/rest/reference/activity#get-a-thread-subscription-for-the-authenticated-user


* Get a thread subscription for the authenticated user
* This checks to see if the current user is subscribed to a thread. You can also [get a repository subscription](https://docs.github.com/rest/reference/activity#get-a-repository-subscription).
 *
 * Note that subscriptions are only generated if a user is participating in a conversation--for example, they've replied to the thread, were **@mentioned**, or manually subscribe to a thread.
* @param threadId - The unique identifier of the pull request thread.
*/
export declare const getThreadSubscriptionForAuthenticatedUser: ApiHeroEndpoint<{
    threadId: number;
}, ThreadSubscription>;
/**
* @see https://docs.github.com/rest/reference/activity#set-a-thread-subscription


* Set a thread subscription
* If you are watching a repository, you receive notifications for all threads by default. Use this endpoint to ignore future notifications for threads until you comment on the thread or get an **@mention**.
 *
 * You can also use this endpoint to subscribe to threads that you are currently not receiving notifications for or to subscribed to threads that you have previously ignored.
 *
 * Unsubscribing from a conversation in a repository that you are not watching is functionally equivalent to the [Delete a thread subscription](https://docs.github.com/rest/reference/activity#delete-a-thread-subscription) endpoint.
* @param threadId - The unique identifier of the pull request thread.
*/
export declare const setThreadSubscription: ApiHeroEndpoint<{
    threadId: number;
    payload?: {
        /**
         * Whether to block all notifications from a thread.
         */
        ignored?: boolean;
    };
}, ThreadSubscription>;
/**
* @see https://docs.github.com/rest/reference/activity#delete-a-thread-subscription


* Delete a thread subscription
* Mutes all future notifications for a conversation until you comment on the thread or get an **@mention**. If you are watching the repository of the thread, you will still receive notifications. To ignore future notifications for a repository you are watching, use the [Set a thread subscription](https://docs.github.com/rest/reference/activity#set-a-thread-subscription) endpoint and set `ignore` to `true`.
* @param threadId - The unique identifier of the pull request thread.
*/
export declare const deleteThreadSubscription: ApiHeroEndpoint<{
    threadId: number;
}, void>;
