import { BaseGist, GistComment, GistCommit, GistSimple, ApiHeroEndpoint } from "./@types";
/**
* @see https://docs.github.com/rest/reference/gists#list-gists-for-the-authenticated-user


* List gists for the authenticated user
* Lists the authenticated user's gists or if called anonymously, this endpoint returns all public gists:
* @param [perPage=30] - The number of results per page (max 100).
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [page=1] - Page number of the results to fetch.
*/
export declare const list: ApiHeroEndpoint<{
    perPage?: number;
    since?: string;
    page?: number;
}, Array<BaseGist>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#create-a-gist


* Create a gist
* Allows you to add a new gist with one or more files.
 *
 * **Note:** Don't name your files "gistfile" with a numerical suffix. This is the format of the automatic naming scheme that Gist uses internally.
*/
export declare const create: ApiHeroEndpoint<{
    gist: {
        /**
         * Names and content for the files that make up the gist
         *
         * @example
         * {
         *   "hello.rb": {
         *     "content": "puts \"Hello, World!\""
         *   }
         * }
         */
        files: Record<string, {
            /**
             * Content of the file
             */
            content: string;
        }>;
        public?: boolean | "true" | "false";
        /**
         * Description of the gist
         *
         * @example
         * "Example Ruby script"
         */
        description?: string;
    };
}, GistSimple, {
    Location: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#list-public-gists


* List public gists
* List public gists sorted by most recently updated to least recently updated.
 *
 * Note: With [pagination](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination), you can fetch up to 3000 gists. For example, you can fetch 100 pages with 30 gists per page or 30 pages with 100 gists per page.
* @param [perPage=30] - The number of results per page (max 100).
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listPublic: ApiHeroEndpoint<{
    perPage?: number;
    since?: string;
    page?: number;
}, Array<BaseGist>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#list-starred-gists


* List starred gists
* List the authenticated user's starred gists:
* @param [perPage=30] - The number of results per page (max 100).
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listStarred: ApiHeroEndpoint<{
    perPage?: number;
    since?: string;
    page?: number;
}, Array<BaseGist>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#get-a-gist


* Get a gist
* @param gistId - The unique identifier of the gist.
*/
export declare const getGist: ApiHeroEndpoint<{
    gistId: string;
}, GistSimple>;
/**
* @see https://docs.github.com/rest/reference/gists#delete-a-gist


* Delete a gist
* @param gistId - The unique identifier of the gist.
*/
export declare const deleteGist: ApiHeroEndpoint<{
    gistId: string;
}, void>;
/**
* @see https://docs.github.com/rest/reference/gists/#update-a-gist


* Update a gist
* Allows you to update or delete a gist file and rename gist files. Files from the previous version of the gist that aren't explicitly changed during an edit are unchanged.
* @param gistId - The unique identifier of the gist.
*/
export declare const update: ApiHeroEndpoint<{
    gistId: string;
    gist: {
        /**
         * Names of files to be updated
         *
         * @example
         * {
         *   "hello.rb": {
         *     "content": "blah",
         *     "filename": "goodbye.rb"
         *   }
         * }
         */
        files?: Record<string, {
            /**
             * The new content of the file
             */
            content?: string;
            /**
             * The new filename for the file
             */
            filename?: string | null;
        }>;
        /**
         * Description of the gist
         *
         * @example
         * "Example Ruby script"
         */
        description?: string;
    };
}, GistSimple>;
/**
* @see https://docs.github.com/rest/reference/gists#check-if-a-gist-is-starred


* Check if a gist is starred
* @param gistId - The unique identifier of the gist.
*/
export declare const checkIsStarred: ApiHeroEndpoint<{
    gistId: string;
}, void>;
/**
* @see https://docs.github.com/rest/reference/gists#star-a-gist


* Star a gist
* Note that you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
* @param gistId - The unique identifier of the gist.
*/
export declare const star: ApiHeroEndpoint<{
    gistId: string;
}, void>;
/**
* @see https://docs.github.com/rest/reference/gists#unstar-a-gist


* Unstar a gist
* @param gistId - The unique identifier of the gist.
*/
export declare const unstar: ApiHeroEndpoint<{
    gistId: string;
}, void>;
/**
* @see https://docs.github.com/rest/reference/gists#list-gist-forks


* List gist forks
* @param gistId - The unique identifier of the gist.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listForks: ApiHeroEndpoint<{
    gistId: string;
    perPage?: number;
    page?: number;
}, Array<GistSimple>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#fork-a-gist


* Fork a gist
* **Note**: This was previously `/gists/:gist_id/fork`.
* @param gistId - The unique identifier of the gist.
*/
export declare const fork: ApiHeroEndpoint<{
    gistId: string;
}, BaseGist, {
    Location: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#get-a-gist-revision


* Get a gist revision
* @param gistId - The unique identifier of the gist.
* @param sha
*/
export declare const getRevision: ApiHeroEndpoint<{
    gistId: string;
    sha: string;
}, GistSimple>;
/**
* @see https://docs.github.com/rest/reference/gists#list-gists-for-a-user


* List gists for a user
* Lists public gists for the specified user:
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listForUser: ApiHeroEndpoint<{
    username: string;
    perPage?: number;
    since?: string;
    page?: number;
}, Array<BaseGist>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#list-gist-commits


* List gist commits
* @param gistId - The unique identifier of the gist.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listCommits: ApiHeroEndpoint<{
    gistId: string;
    perPage?: number;
    page?: number;
}, Array<GistCommit>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#list-gist-comments


* List gist comments
* @param gistId - The unique identifier of the gist.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
export declare const listComments: ApiHeroEndpoint<{
    gistId: string;
    perPage?: number;
    page?: number;
}, Array<GistComment>, {
    Link: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#create-a-gist-comment


* Create a gist comment
* @param gistId - The unique identifier of the gist.
*/
export declare const createComment: ApiHeroEndpoint<{
    gistId: string;
    comment: {
        /**
         * The comment text.
         *
         * @example
         * "Body of the attachment"
         */
        body: string;
    };
}, GistComment, {
    Location: string;
}>;
/**
* @see https://docs.github.com/rest/reference/gists#get-a-gist-comment


* Get a gist comment
* @param gistId - The unique identifier of the gist.
* @param commentId - The unique identifier of the comment.
*/
export declare const getComment: ApiHeroEndpoint<{
    gistId: string;
    commentId: number;
}, GistComment>;
/**
* @see https://docs.github.com/rest/reference/gists#delete-a-gist-comment


* Delete a gist comment
* @param gistId - The unique identifier of the gist.
* @param commentId - The unique identifier of the comment.
*/
export declare const deleteComment: ApiHeroEndpoint<{
    gistId: string;
    commentId: number;
}, void>;
/**
* @see https://docs.github.com/rest/reference/gists#update-a-gist-comment


* Update a gist comment
* @param gistId - The unique identifier of the gist.
* @param commentId - The unique identifier of the comment.
*/
export declare const updateComment: ApiHeroEndpoint<{
    gistId: string;
    commentId: number;
    comment: {
        /**
         * The comment text.
         *
         * @example
         * "Body of the attachment"
         */
        body: string;
    };
}, GistComment>;
